/**
 * 项目：视频监控平台
 * 模型分组：用户管理
 * 模型名称：权限表
 * @Author: xiongwei
 * @Date: 2024-09-26 11:50:00
 */

import { BasicColumn } from '@/components/Table';
import { FormSchema } from '@/components/Table';




const colProps = { xs: { span: 24 }, sm: { span: 24 }, lg: { span: 8 } };
const colPropsInDrawer = { span: 24 };

export const schema = {
  model: 'Authority',
  viewInPage: false,
  properties: [
    {
      field: 'id',
      label: 'Id',
      defaultValue: undefined,
      form: {
        componentProps: {
          allowClear: false,
          placeholder: 'Id',
        },
        colProps,
        component: 'InputNumber',
        rules: [{ required: true, message: '请输入Id！' }],
      },
      table: {
      },
    },
    {
      field: 'parentId',
      label: '父级Id',
      defaultValue: 0,
      form: {
        componentProps: {
          allowClear: false,
          placeholder: '父级Id',
        },
        colProps,
        component: 'InputNumber',
        rules: [{ required: true, message: '请输入父级Id！' }],
      },
      table: {
      },
    },
    {
      field: 'name',
      label: '名称',
      defaultValue: undefined,
      form: {
        componentProps: {
          allowClear: false,
          placeholder: '名称',
        },
        colProps,
        component: 'Input',
        rules: [{ required: true, message: '请输入名称！' }],
      },
      table: {
      },
    },
    {
      field: 'createTime',
      label: 'CreateTime',
      defaultValue: undefined,
      form: {
        colProps,
        componentProps: {
          allowClear: false,
          placeholder: ['开始时间', '结束时间'],
          format: 'YYYY-MM-DD',
          valueFormat: 'YYYY-MM-DD',
          showTime: false,
        },
        component: 'RangePicker',
        rules: [{ required: true, message: '请输入CreateTime！' }],
      },
      table: {
      },
    },
    {
      field: 'updateTime',
      label: 'UpdateTime',
      defaultValue: undefined,
      form: {
        colProps,
        componentProps: {
          allowClear: false,
          placeholder: ['开始时间', '结束时间'],
          format: 'YYYY-MM-DD',
          valueFormat: 'YYYY-MM-DD',
          showTime: false,
        },
        component: 'RangePicker',
        rules: [{ required: true, message: '请输入UpdateTime！' }],
      },
      table: {
      },
    },
  ],
};

const queryFields = ['name'];
const editFields = ['parentId','name'];
const tableFields = ['name','createTime','updateTime'];
const descriptionFields = ['parentId','name','createTime','updateTime'];

const queryFieldsIndexMap = new Map(queryFields.map((field, index) => [field, index]));
export const searchFormSchema: FormSchema[] = schema.properties.filter(item => queryFields.includes(item.field))
  .map(
    ({ field, label, form: { ...formProps } }) =>
      ({
        field,
        label,
        defaultValue: undefined,
        ...formProps,
        required: false,
        rules: [{ required: false }],
      } as FormSchema),
  )
 .sort((a, b) => {
   const indexA = queryFieldsIndexMap.get(a.field) as number;
   const indexB = queryFieldsIndexMap.get(b.field) as number;
   return indexA - indexB;
 });

const editFieldsIndexMap = new Map(editFields.map((field, index) => [field, index]));
export const formSchema: FormSchema[] = schema.properties.filter(item => editFields.includes(item.field))
  .map(
    ({ field, label, defaultValue, form }) =>
      ({
        field,
        label,
        defaultValue,
        ...form,
        colProps: colPropsInDrawer,
      } as FormSchema),
  )
  .sort((a, b) => {
      const indexA = editFieldsIndexMap.get(a.field) as number;
      const indexB = editFieldsIndexMap.get(b.field) as number;
      return indexA - indexB;
  });

const tableFieldsIndexMap = new Map(tableFields.map((field, index) => [field, index]));
export const columns: BasicColumn[] = schema.properties.filter(item => tableFields.includes(item.field))
  .map(
    ({ field, label, table }) =>
      ({
        dataIndex: field,
        title: label,
        ...table,
      } as BasicColumn)
  )
  .sort((a, b) => {
     const indexA = tableFieldsIndexMap.get(a.dataIndex as string) as number;
     const indexB = tableFieldsIndexMap.get(b.dataIndex as string) as number;
     return indexA - indexB;
  });

const descriptionFieldsIndexMap = new Map(descriptionFields.map((field, index) => [field, index]));
export const descriptionColumns: BasicColumn[] = schema.properties.filter(item => descriptionFields.includes(item.field))
  .map(
    ({ field, label, table }) =>
      ({
        dataIndex: field,
        title: label,
        ...table,
      } as BasicColumn),
  )
  .sort((a, b) => {
      const indexA = descriptionFieldsIndexMap.get(a.dataIndex as string) as number;
      const indexB = descriptionFieldsIndexMap.get(b.dataIndex as string) as number;
      return indexA - indexB;
  });
