/**
 * 项目：视频监控平台
 * 模型分组：用户管理
 * 模型名称：用户权限对应表
 * @Author: xiongwei
 * @Date: 2024-09-26 11:50:00
 */

import { BasicColumn } from '@/components/Table';
import { FormSchema } from '@/components/Table';




const colProps = { xs: { span: 24 }, sm: { span: 24 }, lg: { span: 8 } };
const colPropsInDrawer = { span: 24 };

export const schema = {
  model: 'UserAuthority',
  viewInPage: false,
  properties: [
    {
      field: 'id',
      label: 'ID系统自动生成',
      defaultValue: undefined,
      form: {
        componentProps: {
          allowClear: false,
          placeholder: 'ID系统自动生成',
        },
        colProps,
        component: 'InputNumber',
        rules: [{ required: true, message: '请输入ID系统自动生成！' }],
      },
      table: {
      },
    },
    {
      field: 'userId',
      label: 'sys_user.id',
      defaultValue: undefined,
      form: {
        componentProps: {
          allowClear: false,
          placeholder: 'sys_user.id',
        },
        colProps,
        component: 'InputNumber',
        rules: [{ required: true, message: '请输入sys_user.id！' }],
      },
      table: {
      },
    },
    {
      field: 'authorityId',
      label: 'sys_authority.id',
      defaultValue: undefined,
      form: {
        componentProps: {
          allowClear: false,
          placeholder: 'sys_authority.id',
        },
        colProps,
        component: 'InputNumber',
        rules: [{ required: true, message: '请输入sys_authority.id！' }],
      },
      table: {
      },
    },
  ],
};

const queryFields = ['id','userId','authorityId'];
const editFields = ['userId','authorityId'];
const tableFields = ['userId','authorityId'];
const descriptionFields = ['userId','authorityId'];

const queryFieldsIndexMap = new Map(queryFields.map((field, index) => [field, index]));
export const searchFormSchema: FormSchema[] = schema.properties.filter(item => queryFields.includes(item.field))
  .map(
    ({ field, label, form: { ...formProps } }) =>
      ({
        field,
        label,
        defaultValue: undefined,
        ...formProps,
        required: false,
        rules: [{ required: false }],
      } as FormSchema),
  )
 .sort((a, b) => {
   const indexA = queryFieldsIndexMap.get(a.field) as number;
   const indexB = queryFieldsIndexMap.get(b.field) as number;
   return indexA - indexB;
 });

const editFieldsIndexMap = new Map(editFields.map((field, index) => [field, index]));
export const formSchema: FormSchema[] = schema.properties.filter(item => editFields.includes(item.field))
  .map(
    ({ field, label, defaultValue, form }) =>
      ({
        field,
        label,
        defaultValue,
        ...form,
        colProps: colPropsInDrawer,
      } as FormSchema),
  )
  .sort((a, b) => {
      const indexA = editFieldsIndexMap.get(a.field) as number;
      const indexB = editFieldsIndexMap.get(b.field) as number;
      return indexA - indexB;
  });

const tableFieldsIndexMap = new Map(tableFields.map((field, index) => [field, index]));
export const columns: BasicColumn[] = schema.properties.filter(item => tableFields.includes(item.field))
  .map(
    ({ field, label, table }) =>
      ({
        dataIndex: field,
        title: label,
        ...table,
      } as BasicColumn)
  )
  .sort((a, b) => {
     const indexA = tableFieldsIndexMap.get(a.dataIndex as string) as number;
     const indexB = tableFieldsIndexMap.get(b.dataIndex as string) as number;
     return indexA - indexB;
  });

const descriptionFieldsIndexMap = new Map(descriptionFields.map((field, index) => [field, index]));
export const descriptionColumns: BasicColumn[] = schema.properties.filter(item => descriptionFields.includes(item.field))
  .map(
    ({ field, label, table }) =>
      ({
        dataIndex: field,
        title: label,
        ...table,
      } as BasicColumn),
  )
  .sort((a, b) => {
      const indexA = descriptionFieldsIndexMap.get(a.dataIndex as string) as number;
      const indexB = descriptionFieldsIndexMap.get(b.dataIndex as string) as number;
      return indexA - indexB;
  });
